# ReplaceLCM.ps1
#
# This Powershell script recursively replaces all references of text within
# a directory hierarchy.  If the specified directory contains subdirectories,
# it will recursively descend into all subdirectories and repeat the process.
# Only xml and csv files are inspected and updated.
#
# Syntax:  powershell D:\Scripts\ReplaceLCM.ps1 -editDir <directory name> -old '<old text>' -new '<new text>'
# Example: powershell D:\Scripts\ReplaceLCM.ps1 -editDir D:\snapshot -old planning-test -new planning
#
# If the values supplied to either -old or -new must contain spaces,
# then those values should be enclosed with single quote (') characters.
#
# If you receive a security policy error about “unsigned” Powershell scripts when 
# running this process, open a command prompt and type:
# powershell.exe Set-ExecutionPolicy Unrestricted
#
#  Written on 05/01/2017 by Dave Shay (Datavail)
# Modified on MM/DD/YYYY by Your Name - Briefly describe changes

param($editDir, $old, $new)

# If you're having trouble, uncomment the 3 lines below to see debugging information
#Write-Host Folder passed to us is $editDir
#Write-Host Text to replace is $old
#Write-Host Replacement text is $new

$editFiles=Get-ChildItem "$editDir" -Recurse | Where-Object{$_.name -like "*.xml" -or $_.name -like "*.csv"}

# Replace the content of the files
foreach ($file in $editFiles)
{
	if(Select-String -CaseSensitive $file.PSPath -pattern "$old")
	{
		Write-Host Found matching text within $file.FullName
		
		(Get-Content $file.PSPath) | 
		Foreach-Object {$_ -replace "$old", "$new"} | 
		Set-Content $file.PSPath
	}
}

# Rename the group xml files
Get-ChildItem "$editDir" -Filter "$old*" -Recurse | Where-Object{$_.name -like "*.xml" -or $_.name -like "*.csv"} | Rename-Item -NewName {$_.name -replace "$old","$new"}